List the tables published in a dataset
Arguments
- dataset
Short dataset id (e.g.
"dfp").- group
Optional CKAN group slug (e.g.
"companhias"). WhenNULL(default), the function resolves the group by uniqueness across the installed schema tree; when a dataset slug occurs in more than one group (a v0.4+ possibility), omittinggroupaborts withcvmdata_error_input_ambiguous.
See also
Other discovery:
cvm_codelist(),
cvm_dataset_years(),
cvm_datasets(),
cvm_dictionary(),
cvm_groups()
Examples
cvm_tables("dfp")
#> [1] "bpa" "bpp" "composicao_capital"
#> [4] "dfc_md" "dfc_mi" "dmpl"
#> [7] "dra" "dre" "dva"
#> [10] "parecer" "submissao"
cvm_tables("dfp", group = "companhias")
#> [1] "bpa" "bpp" "composicao_capital"
#> [4] "dfc_md" "dfc_mi" "dmpl"
#> [7] "dra" "dre" "dva"
#> [10] "parecer" "submissao"